@@ -246,7 +246,7 @@ class QuantEngineClient:
             if tick_data.LastTick:
                 self.ProgressPercent = 100
 
-        if progress_percent >= 1 or tick_data.LastTick:
+        if progress_percent >= 0.1 or progress_percent == 0 or tick_data.LastTick:
             if not tick_data.LastTick:
                 self.ProgressPercent += progress_percent
 
